@@ -13,8 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import base64
-
 from functionaltests.cli.base import CmdLineTestCase
 from functionaltests.cli.v1.behaviors.secret_behaviors import SecretBehaviors
 from functionaltests.common import keys
@@ -39,8 +37,8 @@ class SecretTestCase(CmdLineTestCase):
         'symmetric': ['symmetric',
                       'aes',
                       '128',
-                      ('\x00\x01\x02\x03\x04\x05\x06\x07'
-                       '\x00\x01\x02\x03\x04\x05\x06\x07')],
+                      (b'\x00\x01\x02\x03\x04\x05\x06\x07'
+                       b'\x00\x01\x02\x03\x04\x05\x06\x07')],
         'private': ['private',
                     'rsa',
                     '2048',
@@ -65,7 +63,7 @@ class SecretTestCase(CmdLineTestCase):
     @testcase.attr('positive')
     def test_secret_store_with_secret_type(self, secret_type, algorithm,
                                            bit_length, secret):
-        payload = base64.b64encode(secret)
+        payload = secret
         secret_argv = ['--secret-type', secret_type]
         if algorithm:
             secret_argv.extend(['--algorithm', algorithm])
@@ -134,3 +132,19 @@ class SecretTestCase(CmdLineTestCase):
         payload = self.secret_behaviors.get_secret_payload(secret_href,
                                                            raw=True)
         self.assertEqual(payload, self.expected_payload)
+
+    @testcase.attr('positive')
+    def test_secret_file_parameter_read(self):
+        secret_href = self.secret_behaviors.store_secret(
+            payload=self.expected_payload)
+        self.secret_behaviors.get_secret_file(secret_href=secret_href)
+        payload = self.secret_behaviors.read_secret_test_file()
+        self.assertEqual(payload, self.expected_payload)
+
+    @testcase.attr('positive')
+    def test_secret_file_parameter_write(self):
+        self.secret_behaviors.write_secret_test_file(
+            payload=self.expected_payload)
+        secret_href = self.secret_behaviors.store_secret_file()
+        payload = self.secret_behaviors.get_secret_payload(secret_href)
+        self.assertEqual(payload, self.expected_payload)
